## 东方财富概念板块

接口：dc_index

描述：获取东方财富每个交易日的概念板块数据，支持按日期查询

限量：单次最大可获取5000条数据，历史数据可根据日期循环获取

权限：用户积累6000积分可调取，具体请参阅积分获取办法 

注意：本接口只限个人学习和研究使用，如需商业用途，请自行联系东方财富解决数据采购问题。





输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 指数代码（支持多个代码同时输入，用逗号分隔） |
| name | str | N | 板块名称（例如：人形机器人） |
| trade_date | str | N | 交易日期（YYYYMMDD格式，下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 概念代码 |
| trade_date | str | Y | 交易日期 |
| name | str | Y | 概念名称 |
| leading | str | Y | 领涨股票名称 |
| leading_code | str | Y | 领涨股票代码 |
| pct_change | float | Y | 涨跌幅 |
| leading_pct | float | Y | 领涨股票涨跌幅 |
| total_mv | float | Y | 总市值（万元） |
| turnover_rate | float | Y | 换手率 |
| up_num | int | Y | 上涨家数 |
| down_num | int | Y | 下降家数 |

接口示例

```python
#获取东方财富2025年1月3日的概念板块列表
df = pro.dc_index(trade_date='20250103', fields='ts_code,name,turnover_rate,up_num,down_num')
```

数据示例

```python
ts_code   name       turnover_rate  up_num  down_num
0    BK1186.DC   首发经济        8.3700       4        31
```